<?php
$translations = array(
	'General_Locale' => 'pt_BR.UTF-8',
	'General_TranslatorName' => 'Marcos Napier, Marcela Ferraro, Zob,Raphael Milani',
	'General_TranslatorEmail' => 'marcusbacus@gmail.com, mah_ferraro@yahoo.com.br , ramilani@gmail.com',
	'General_EnglishLanguageName' => 'Brazilian Portuguese',
	'General_OriginalLanguageName' => 'Português brasileiro',
	'General_HelloUser' => 'Olá, %s!',
	'General_Dashboard' => 'Painel de Ferramentas',
	'General_DashboardForASpecificWebsite' => 'Painel de Ferramentas para um site especifico',
	'General_MultiSitesSummary' => 'Todos os sites',
	'General_AllWebsitesDashboard' => 'Painel de Ferramentas de Todos os sites',
	'General_Settings' => 'Configurações',
	'General_GiveUsYourFeedback' => 'Dê o seu feedback!',
	'General_Unknown' => 'Desconhecido',
	'General_Never' => 'Nunca',
	'General_Required' => '%s necessário',
	'General_NotValid' => '%s não é válido',
	'General_NotDefined' => '%s não definido',
	'General_Error' => 'Erro',
	'General_Warning' => 'Aviso',
	'General_BackToHomepage' => 'Voltar a página do Piwik',
	'General_Yes' => 'Sim',
	'General_No' => 'Não',
	'General_Delete' => 'Apagar',
	'General_Report' => 'Relatório',
	'General_Reports' => 'Relatórios',
	'General_RelatedReport' => 'Relatório Relacionado',
	'General_RelatedReports' => 'Relatórios Relacionados',
	'General_Metric' => 'Métrica',
	'General_Metrics' => 'Métricas',
	'General_Edit' => 'Editar',
	'General_Download' => 'Baixar',
	'General_Close' => 'Fechar',
	'General_Cancel' => 'Cancelar',
	'General_OrCancel' => 'ou %s Cancele %s',
	'General_Logout' => 'Sair',
	'General_Username' => 'Nome de Usuário',
	'General_Description' => 'Descrição',
	'General_Done' => 'Pronto',
	'General_MetricsToPlot' => 'Métricas para "plotar"',
	'General_RowsToDisplay' => 'Linhas para visualizar',
	'General_MetricToPlot' => 'Métrica para "plotar"',
	'General_RecordsToPlot' => 'Registros para "plotar"',
	'General_Name' => 'Nome',
	'General_Value' => 'Valor',
	'General_AverageOrderValue' => 'Média de Pedidos',
	'General_PurchasedProducts' => 'Produtos Adquiridos',
	'General_EcommerceOrders' => 'Pedidos',
	'General_TotalRevenue' => 'Total de Revendas',
	'General_ProductRevenue' => 'Produto Revendido',
	'General_AveragePrice' => 'Média de Preço',
	'General_AverageQuantity' => 'Média Qualidade',
	'General_UniquePurchases' => 'Pedidos únicos',
	'General_Quantity' => 'Quantidade',
	'General_Price' => 'Preço',
	'General_Subtotal' => 'Subtoal',
	'General_Tax' => 'Taxas',
	'General_Shipping' => 'Envio',
	'General_Discount' => 'Desconto',
	'General_Details' => 'Detalhes',
	'General_Default' => 'Padrão',
	'General_Visit' => 'Visita',
	'General_FromReferrer' => 'origem',
	'General_VisitorIP' => 'IP do Visitante',
	'General_VisitorID' => 'Visitante ID',
	'General_VisitType' => 'Tipo do Visitante',
	'General_DaysSinceLastVisit' => 'Dias desde a última visita',
	'General_DaysSinceFirstVisit' => 'Dias desde a primeira visita',
	'General_DaysSinceLastEcommerceOrder' => 'Dias desde o último pedido',
	'General_NumberOfVisits' => 'Número de visitantes',
	'General_VisitConvertedGoalId' => 'Visita convertida em uma específica Meta',
	'General_VisitConvertedNGoals' => 'Visita convertida %s Objetivos',
	'General_NewVisitor' => 'Novo visitante',
	'General_NewVisits' => 'Novos visitantes',
	'General_ReturningVisitor' => 'Retorno do Visitante',
	'General_Visitor' => 'Visitante',
	'General_Date' => 'Data',
	'General_Period' => 'Período',
	'General_ChooseDate' => 'Escolha a Data',
	'General_Today' => 'Hoje',
	'General_Yesterday' => 'Ontem',
	'General_CurrentWeek' => 'Semana atual',
	'General_CurrentMonth' => 'Mês atual',
	'General_CurrentYear' => 'Ano atual',
	'General_DateRange' => 'Entre as datas:',
	'General_DateRangeInPeriodList' => 'Período Datas',
	'General_DateRangeFromTo' => 'De %s para %s',
	'General_ApplyDateRange' => 'Aplicar para este período',
	'General_InvalidDateRange_js' => 'Período de datas inválido , Por favor tente novamente',
	'General_DateRangeFrom_js' => 'De',
	'General_DateRangeTo_js' => 'Para',
	'General_LoadingData' => 'Carregando dados...',
	'General_Loading_js' => 'Carregando...',
	'General_GoTo' => 'Ir para %s',
	'General_Next' => 'Próximo',
	'General_Previous' => 'Anterior',
	'General_First' => 'Primeiro',
	'General_Search' => 'Pesquisar',
	'General_Others' => 'Outros',
	'General_Table' => 'Tabela',
	'General_Piechart' => 'Gráfico circular',
	'General_TagCloud' => 'Núvem de Tag',
	'General_VBarGraph' => 'Gráfico de barras verticais',
	'General_View' => 'Visualização',
	'General_OpenInNewWindow_js' => 'Abre uma nova janela',
	'General_SaveImageOnYourComputer_js' => 'Para salvar a imagem em seu computador, clique com o direito na imagem e selecione "Salvar Imagem Como..."',
	'General_Refresh' => 'Atualizar página',
	'General_Visitors' => 'Visitantes',
	'General_ExportThisReport' => 'Exportar este conjunto de dados noutros formatos',
	'General_ExportAsImage_js' => 'Exportar como imagem',
	'General_Export' => 'Exportar',
	'General_YourChangesHaveBeenSaved' => 'Suas alterações foram salvas',
	'General_ErrorRequest' => 'Oops… problema durante a sua requisição, por favor, tente novamente.',
	'General_ColumnNbUniqVisitors' => 'Visitantes Únicos',
	'General_ColumnNbVisits' => 'Visitas',
	'General_ColumnPercentageVisits' => '% Visitas',
	'General_ColumnNbActions' => 'Ações',
	'General_NbActions' => 'Número de Ações',
	'General_ColumnMaxActions' => 'Ações máximas em uma visita',
	'General_ColumnSumVisitLength' => 'Tempo total gasto pelos visitantes (em segundos)',
	'General_ColumnLabel' => 'Rótulo',
	'General_ColumnConversionRate' => 'Taxa de conversão',
	'General_ColumnActionsPerVisit' => 'Ações por visita',
	'General_VisitDuration' => 'Média da duração das visitas (em segundos)',
	'General_ColumnAvgTimeOnSite' => 'Tempo médio no site',
	'General_ColumnVisitDuration' => 'Duração da Visita em segundos',
	'General_ColumnBounceRate' => 'Taxa de saída',
	'General_ColumnExitRate' => 'Taxa de saída',
	'General_ColumnPageviews' => 'Exibições da página',
	'General_ColumnUniquePageviews' => 'Exbições únicas da página',
	'General_ColumnBounces' => 'Saídas',
	'General_ColumnUniqueEntrances' => 'Entradas únicas',
	'General_ColumnEntrances' => 'Entradas',
	'General_ColumnExits' => 'Saídas',
	'General_ColumnAverageTimeOnPage' => 'Média de tempo na página',
	'General_ColumnValuePerVisit' => 'Valor por visita',
	'General_ColumnVisitsWithConversions' => 'Visitas com conversões',
	'General_YearsDays' => '%1$s anos %2$s dias',
	'General_DaysHours' => '%1$s dias %2$s horas',
	'General_HoursMinutes' => '%1$s horas %2$s minutos',
	'General_MinutesSeconds' => '%1$s minutos %2$s segundos',
	'General_Seconds' => '%s segundos',
	'General_Save' => 'Salvar',
	'General_ForExampleShort' => 'ex.',
	'General_YouMustBeLoggedIn' => 'Tem de estar ligado para aceder a essa funcionalidade.',
	'General_GeneralSettings' => 'Configurações Gerais',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Permitir que o Piwik salve numa trigger quando relatórios são vistos do navegador',
	'General_ArchivingInlineHelp' => 'Para sites com tráfego de médio a alto, é recomendado desabilitar a trigger que salva do navegador. Em vez disso, nós recomendamos que instale um cron job para processar os relatorios Piwik a cada hora.',
	'General_ArchivingTriggerDescription' => 'Recomendado para instalações maiores do Piwik, precisa de %s configurar um cron job%s para processar os relatórios automaticamente.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Veja a  %s documentação oficial%s para mais informações.',
	'General_NSeconds' => '%s segundos',
	'General_SmallTrafficYouCanLeaveDefault' => 'Para sites com tráfego baixo, você pode deixar o padrão de %s segundos, e acessar todos os relatórios em tempo real.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Para sites com tráfego de médio a alto, nós recomendamos processar relatórios diariamente no máximo a cada meia hora(%s segundos)ou toda hora (%s segundos).',
	'General_RequiresFlash' => 'Mostrar gráficos no Piwik requer Flash',
	'General_GraphHelp' => 'Mais informações sobre mostrar gráficos em Piwik.',
	'General_NoDataForGraph' => 'Sem dados para este gráfico',
	'General_NoDataForTagCloud' => 'Sem dados para esta nuvem de tags',
	'General_DisplaySimpleTable' => 'Apresentar tabela simples.',
	'General_DisplayTableWithMoreMetrics' => 'Apresentar a tabela com mais detalhes',
	'General_DisplayTableWithGoalMetrics' => 'Apresentar a tabela com os detalhes dos objectivos',
	'General_YouAreViewingDemoShortMessage' => 'Está atualmente a ver a demonstração do Piwik',
	'General_DownloadFullVersion' => '%1$sBaixar%2$s a versão completa! Ver %3$s',
	'General_NewUpdatePiwikX' => 'Nova atualização: Piwik %s',
	'General_AboutPiwikX' => 'Sobre o Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwiki %1$s está disponível. %2$s Por favor atualize agora!%3$s (veja %4$sas mudanças%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s está disponível. Por favor notifique o administrador do site.',
	'General_NewReportsWillBeProcessedByCron' => 'Quando o arquivamento do Piwik não for iniciado pelo navegador, novos relatórios irão ser processados pelo crontab.',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Os relatórios irão então ser processados no máximo a cada hora.',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Assumindo que o arquivamento é rápido para as suas configurações, você pode programar o crontab para funcionar com mais frequência.',
	'General_BackToPiwik' => 'Volta ao Piwik',
	'General_ShortMonth_2' => 'Fev',
	'General_ShortMonth_4' => 'Abr',
	'General_ShortMonth_5' => 'Mai',
	'General_ShortMonth_8' => 'Ago',
	'General_ShortMonth_9' => 'Set',
	'General_ShortMonth_10' => 'Out',
	'General_ShortMonth_12' => 'Dez',
	'General_LongMonth_1' => 'Janeiro',
	'General_LongMonth_2' => 'Fevereiro',
	'General_LongMonth_3' => 'Março',
	'General_LongMonth_4' => 'Abril',
	'General_LongMonth_5' => 'Maio',
	'General_LongMonth_6' => 'Junho',
	'General_LongMonth_7' => 'Julho',
	'General_LongMonth_8' => 'Agosto',
	'General_LongMonth_9' => 'Setembro',
	'General_LongMonth_10' => 'Outubro',
	'General_LongMonth_11' => 'Novembro',
	'General_LongMonth_12' => 'Dezembro',
	'General_ShortDay_1' => 'Seg',
	'General_ShortDay_2' => 'Ter',
	'General_ShortDay_3' => 'Qua',
	'General_ShortDay_4' => 'Qui',
	'General_ShortDay_5' => 'Sex',
	'General_ShortDay_6' => 'Sáb',
	'General_ShortDay_7' => 'Dom',
	'General_LongDay_1' => 'Segunda',
	'General_LongDay_2' => 'Terça',
	'General_LongDay_3' => 'Quarta',
	'General_LongDay_4' => 'Quinta',
	'General_LongDay_5' => 'Sexta',
	'General_LongDay_6' => 'Sábado',
	'General_LongDay_7' => 'Domingo',
	'General_Daily' => 'Diáriamente',
	'General_Weekly' => 'Semanalmente',
	'General_Monthly' => 'Mensalmente',
	'General_ConfigFileIsNotWritable' => 'O arquivo %s de configuração Piwik não é editável, suas mudanças não serão salvas. %s por favor mude as permissões da configuração do arquivo para fazê-lo editável.',
	'General_ExceptionDatabaseVersion' => 'Sua %1$s versão é %2$s mas o Piwik requer no mínimo %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Sua %1$s client version é %2$s que é incompatível com a versão do servidor %3$s.',
	'General_ExceptionMissingFile' => 'Arquivo faltando: %s.',
	'General_ExceptionFilesizeMismatch' => 'Tamanho do arquivo incompatível: %1$s  (esperado: %2$s, encontrado: %3$s)',
	'General_ExceptionFileIntegrity' => 'Check de inegridade falhou: %s.',
	'General_ExceptionNonceMismatch' => 'Não conseguiria verificar a segurança tomada nesse modelo.',
	'General_PleaseSpecifyValue' => 'Por favor, especifique um valor para \'%s\'.',
	'General_ExceptionMethodNotFound' => 'O método \'%s\' não existe ou não está disponível no módulo \'%s\'.',
	'General_ExceptionInvalidRendererFormat' => 'Formato de renderização \'%s\' não válido. Tente algum dos seguintes como alternativa: %s',
	'General_ExceptionInvalidPeriod' => 'O periodo \'%s\' não é suportado. Tente algum dos seguintes como alternativa: %s',
	'General_ExceptionInvalidDateRange' => 'A data %s não está numa gama de datas correcta. Deverá ter o seguinte formato: %s.',
	'General_ExceptionGoalNotFound' => 'O objectivo id=%s não foi encontrado.',
	'General_ExceptionUndeletableFile' => 'Impossível de apagar %s',
	'General_ExceptionPrivilege' => 'Não pode aceder a este recurso uma vez que ele requer um acesso %s.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Não pode aceder a este recurso uma vez que ele requer um acesso %s para pelo menos um site.',
	'General_ExceptionPrivilegeAccessWebsite' => 'Não pode aceder a este recurso uma vez que ele requer um acesso %s para o site id=%d.',
	'General_ExceptionInvalidArchiveTimeToLive' => 'O tempo de arquivamento para hoje tem de ser um número de segundos maior do que zero.',
	'General_ExceptionConfigurationFileNotFound' => 'O ficheiro de configuração {%s} não foi encontrado.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'O ficheiro de configuração {%s} não pôde ser lido. O seu alojamento pode ter destivado %s.',
	'General_ExceptionInvalidToken' => 'O token não é válido.',
	'General_ExceptionInvalidDateFormat' => 'O formato da data tem de ser: %s ou alguma das palavras chave suportadas pela função %s (ver %s para mais informações)',
	'General_ExceptionLanguageFileNotFound' => 'Ficheiro de idioma %s não encontrado.',
	'General_WarningFileIntegritySkipped' => 'Ambiente de desenvolvimento encontrado. Check de integridade de arquivo pulado.',
	'General_WarningFileIntegrityNoManifest' => 'O check de integridade do arquivo não pode ser feita enquanto estiver faltando manifest.inc.php.',
	'General_WarningFileIntegrityNoMd5file' => 'O check de integridade do arquivo não pode ser completado enquanto estiver faltando a função md5_file().',
	'General_FileIntegrityWarningExplanation' => 'O check de integridade do arquivo falhou e reportou alguns erros. Isso é mais provável devido a uma parcial ou upload falho de algum arquivo Piwik. Você deveria refazer o upload de todos os arquivos Piwik e atualizar a página até que nenhum erro seja exibido.',
	'General_UseSMTPServerForEmail' => 'Usar servidor SMTP para o email.',
	'General_SmtpServerAddress' => 'Endereço do servidor SMTP',
	'General_SmtpPort' => 'Porta SMTP',
	'General_AuthenticationMethodSmtp' => 'Método de autenticação para SMTP',
	'General_SmtpUsername' => 'Nome de usuário SMTP',
	'General_SmtpPassword' => 'Password SMTP',
	'General_SmtpEncryption' => 'Criptografia SMTP',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Selecione "Sim" se pretende ou precisa de enviar email através de um nome de servidor em vez de usar a função de email local.',
	'General_OnlyUsedIfUserPwdIsSet' => 'Usado apenas se um nome de usuário e palavra chave estiverem definidas. Pergunte ao seu fornecedor se não tem a certeza de qual método deve usar.',
	'General_OnlyEnterIfRequired' => 'Insira um nome de usuário SMTP apenas se o servidor necessitar de um.',
	'General_OnlyEnterIfRequiredPassword' => 'Insira uma palavra chave SMTP apenas se o servidor necessitar de uma.',
	'General_InvalidResponse' => 'Os dados introduzidos são inválidos.',
	'General_ChooseLanguage' => 'Escolha o idioma.',
	'General_ChoosePeriod' => 'Escolha o período.',
	'General_ChooseWebsite' => 'Escolha o site',
	'General_Language' => 'Idioma',
	'General_PleaseUpdatePiwik' => 'Por favor atualize o seu Piwik',
	'General_RequestTimedOut' => 'O pedido de informação %s expirou. Por favor tente novamente.',
	'General_Recommended' => 'Recomendado',
	'General_NotRecommended' => 'Não recomendado',
	'General_Goal' => 'Objetivo',
	'General_Outlink' => 'Saída',
	'General_Help' => 'Ajuda',
	'General_DailySum' => 'Soma diariamente',
	'General_AfterEntry' => 'Após entrar aqui',
	'General_Metadata' => 'Metadados',
	'General_OneVisit' => '1 visita',
	'General_OneDay' => '1 dia',
	'General_MainMetrics' => 'Métricas principais',
	'General_Rows' => 'Linhas',
	'General_GeneralInformation' => 'Informações Gerais',
	'Actions_PluginDescription' => 'Relatórios sobre visualização de páginas, links externos e downaloads. Rastramentos de links externos e downloads é automático!',
	'Actions_Actions' => 'Ações',
	'Actions_SubmenuPages' => 'Páginas',
	'Actions_SubmenuPagesEntry' => 'Páginas de entrada',
	'Actions_SubmenuPagesExit' => 'Páginas de saída',
	'Actions_EntryPageTitles' => 'Título de Páginas de Entradas',
	'Actions_ExitPageTitles' => 'Título de Páginas de Saídas',
	'Actions_SubmenuPageTitles' => 'Títulos das páginas',
	'Actions_PageUrls' => 'URLs de Página(s)',
	'Actions_SubmenuOutlinks' => 'Links Externos',
	'Actions_PagesReportDocumentation' => 'Este relatório contém informações sobre URL de páginas as quais foram visitadas. %s A tabela está organizada hierarquicamente, as URLs estão apresentadas como estrutura de pastas',
	'Actions_PageTitlesReportDocumentation' => 'Este relatório contém informações sobre títulos de páginas as quais foram visitadas. %s O título da página é um HTML %s Tag a qual é mais visualizada nos títulos do browser.',
	'Actions_OutlinksReportDocumentation' => 'Este relatório mostra a lista de hierarquia de outlinks URLs as quais foram clicadas pelos seus visitantes',
	'Actions_OutlinkDocumentation' => 'Um "outlink" é um link a qual guia o visitante a sair do seu website para outro domínio',
	'Actions_DownloadsReportDocumentation' => 'Neste relatório, você pode ver quais arquivos seus visitantes baixaram. %s Piwik registra como download como um click em um link de download. Se o download foi completado ou não o Piwik não consegue determinar.',
	'Actions_ColumnClicks' => 'Cliques',
	'Actions_ColumnClicksDocumentation' => 'O número de vezes que link foi clicado.',
	'Actions_ColumnUniqueClicks' => 'Cliques únicos',
	'Actions_ColumnUniqueClicksDocumentation' => 'O número de visitantes as quais se acionaram um click no link. Se um link foi clicado várias vezes durante uma visita, isto é somente registrado uma vez.',
	'Actions_ColumnUniqueDownloads' => 'Downloads Únicos',
	'Actions_ColumnPageName' => 'Nome da página',
	'Actions_ColumnPageURL' => 'URL da página',
	'Actions_ColumnClickedURL' => 'URL clicado',
	'AnonymizeIP_PluginDescription' => 'Anonimize o último byte do endereço IP dos visitantes para obedecer suas leis/guias locais de privacidade.',
	'API_PluginDescription' => 'Todos os dados no Piwik estão disponíveis através de APIs simples. Esse plugin é o ponto de entrada para o web service, que você pode chamar para ter seus dados Web Analytics em xml, json, php, csv, etc.',
	'API_QuickDocumentationTitle' => 'API documentação rápida',
	'API_GenerateVisits' => 'Se você não tem nenhum dado hoje, você pode gerar alguns dados usando o plugin %s. Você pode habilitar o plugin %s, então clique no menu "Gerador de Visitantes" na área Piwik Admin.',
	'API_UserAuthentication' => 'Autenticação de usuário',
	'API_UsingTokenAuth' => 'Se você quer %s requisitar dados dentro de um script, um crontab,  etc.  %s você precisa adicionar o parâmetro %s para a API chamar URLS que requerem autenticação.',
	'API_KeepTokenSecret' => 'Esse token_auth é tão secreto quanto seu login e sua senha, %s não compartilhe isso %s!',
	'API_LoadedAPIs' => '%s APIs carregadas com sucesso',
	'CoreAdminHome_PluginDescription' => 'Área Administrativa do Piwik.',
	'CoreAdminHome_MenuGeneralSettings' => 'Configurações Gerais',
	'CoreAdminHome_Administration' => 'Administração',
	'CoreHome_PluginDescription' => 'Estrutura de Relatórios Web Analytics',
	'CoreHome_WebAnalyticsReports' => 'Relatórios Web Analytics',
	'CoreHome_JavascriptDisabled' => 'JavaScript deve ser habilitado para que você possa usar o Piwik como visualização padrão. <br/>Contudo, parece que JavaScript ou está desabilidado ou não é suportado pelo seu navegador. <br/>Para usar a visualização padrão, habilite o JavaScript mudando as opções do seu navegador, então %1$stente novamente%2$s.<br/>',
	'CoreHome_ThereIsNoDataForThisReport' => 'Não existem dados para esse relatório.',
	'CoreHome_CategoryNoData' => 'Sem dados nesta categoria. Tente o "Incluir toda a população".',
	'CoreHome_ShowJSCode' => 'Mostra o código JavaScript a inserir',
	'CoreHome_PageOf_js' => '%1$s de %2$s',
	'CoreHome_PeriodDay' => 'Dia',
	'CoreHome_PeriodWeek' => 'Semana',
	'CoreHome_PeriodMonth' => 'Mês',
	'CoreHome_PeriodYear' => 'Ano',
	'CoreHome_PeriodDays' => 'dias',
	'CoreHome_PeriodWeeks' => 'semanas',
	'CoreHome_PeriodMonths' => 'meses',
	'CoreHome_PeriodYears' => 'anos',
	'CoreHome_DaySu_js' => 'Dom',
	'CoreHome_DayMo_js' => 'Seg',
	'CoreHome_DayTu_js' => 'Ter',
	'CoreHome_DayWe_js' => 'Qua',
	'CoreHome_DayTh_js' => 'Qui',
	'CoreHome_DayFr_js' => 'Sex',
	'CoreHome_DaySa_js' => 'Sáb',
	'CoreHome_ShortDay_1_js' => 'Dom',
	'CoreHome_ShortDay_2_js' => 'Seg',
	'CoreHome_ShortDay_3_js' => 'Ter',
	'CoreHome_ShortDay_4_js' => 'Qua',
	'CoreHome_ShortDay_5_js' => 'Qui',
	'CoreHome_ShortDay_6_js' => 'Sex',
	'CoreHome_ShortDay_7_js' => 'Sáb',
	'CoreHome_LongDay_1_js' => 'Domingo',
	'CoreHome_LongDay_2_js' => 'Segunda',
	'CoreHome_LongDay_3_js' => 'Terça',
	'CoreHome_LongDay_4_js' => 'Quarta',
	'CoreHome_LongDay_5_js' => 'Quinta',
	'CoreHome_LongDay_6_js' => 'Sexta',
	'CoreHome_LongDay_7_js' => 'Sábado',
	'CoreHome_ShortMonth_2_js' => 'Fev',
	'CoreHome_ShortMonth_4_js' => 'Abr',
	'CoreHome_ShortMonth_5_js' => 'Mai',
	'CoreHome_ShortMonth_8_js' => 'Ago',
	'CoreHome_ShortMonth_9_js' => 'Set',
	'CoreHome_ShortMonth_10_js' => 'Out',
	'CoreHome_ShortMonth_12_js' => 'Dez',
	'CoreHome_MonthJanuary_js' => 'Janeiro',
	'CoreHome_MonthFebruary_js' => 'Fevereiro',
	'CoreHome_MonthMarch_js' => 'Março',
	'CoreHome_MonthApril_js' => 'Abril',
	'CoreHome_MonthMay_js' => 'Maio',
	'CoreHome_MonthJune_js' => 'Junho',
	'CoreHome_MonthJuly_js' => 'Julho',
	'CoreHome_MonthAugust_js' => 'Agosto',
	'CoreHome_MonthSeptember_js' => 'Setembro',
	'CoreHome_MonthOctober_js' => 'Outubro',
	'CoreHome_MonthNovember_js' => 'Novembro',
	'CoreHome_MonthDecember_js' => 'Dezembro',
	'CorePluginsAdmin_PluginDescription' => 'Interface de Administração de Plugins',
	'CorePluginsAdmin_PluginsManagement' => 'Gerenciamento de plugins',
	'CorePluginsAdmin_MainDescription' => 'Plugins estendem e expandem a funcionalidade do Piwik. Uma vez que um plugin for instalado, você pode ativá-lo ou desativá-lo aqui.',
	'CorePluginsAdmin_Version' => 'Versão',
	'CorePluginsAdmin_Action' => 'Ação',
	'CorePluginsAdmin_PluginHomepage' => 'Página do Plugin',
	'CorePluginsAdmin_Activated' => 'Ativado',
	'CorePluginsAdmin_Active' => 'Ativo',
	'CorePluginsAdmin_Inactive' => 'Inativo',
	'CorePluginsAdmin_Deactivate' => 'Desativar',
	'CorePluginsAdmin_Activate' => 'Ativar',
	'CoreUpdater_PluginDescription' => 'Mecanismo de update Piwik',
	'CoreUpdater_UpdateTitle' => 'Atualiza',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Atualização do banco de dados requerida',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Seu banco de dados do Piwik está desatualizado e deve ser atualizado antes de continuar.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'O banco de dados do Piwik será atualizado da versão %1$s para a nova versão %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Os seguintes plugins serão atualizados: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Nota importante para grandes instalações Piwik',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Se você tem um grande banco de dados Piwik, atualizações podem levar muito tempo para rodar no navegador. Nesse caso, você pode executar as atualizações da sua linha de comando: %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'Se você não tem permissão para atualizar pela linha de comando e se o Piwik falhou em atualizar (devido a um timeout do banco de dados, timeout do navegador, ou outro problema), você poderá manualmente executar as queries SQL para atualizar o Piwik.',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'Clique aqui para ver e copiar a lista de queries SQL que serão executadas',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => 'Nota: se você executar manualmente essas queries, é esperado que algumas delas falhem. Nesse caso, simplesmente ignore os erros, e rode os próximos da lista.',
	'CoreUpdater_ReadyToGo' => 'Pronto(a) para ir?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'O processo de atualização do banco de dados pode levar algum tempo, por favor seja paciente.',
	'CoreUpdater_UpgradePiwik' => 'Atualiza o Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'Se você é um usuário avançado e encontrou um erro na atualização do banco de dados:',
	'CoreUpdater_ErrorDIYHelp_1' => 'identifique e corrija a fonte do problema (ex: memory_limit ou max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'Executar as queries remanescentes que falharam na atualização',
	'CoreUpdater_ErrorDIYHelp_3' => 'Atualiza manualmente a tabela `option` no banco de dados Piwik, ajustando o valor de version_core para a versão da atualização que falhou',
	'CoreUpdater_ErrorDIYHelp_4' => 'roda novamente o script de atualização (através do navegador ou da linha de comando) para continuar com as atualizações restantes',
	'CoreUpdater_ErrorDIYHelp_5' => 'relate o problema (e solução) para que o Piwik possa ser melhorado',
	'CoreUpdater_HelpMessageContent' => 'Verifique o %1$s Piwik FAQ %2$s que explica os erros mais comuns durante a atualização. %3$s Pergunte ao seu administrador do sistema - Ele pode ser capaz de lhe ajudar com o erro que muito provavelmente é relacionado com o seu servidor ou o setup do MySQL.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Erro crítico durante o processo de atualização:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Acima está a mensagem de erro principal. Ela deve ajudar a explicar a causa, mas se você precisar de mais ajuda por favor:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'A atualização se completou com sucesso, contudo houve alguns problemas durante o processo. Por favor leia a descrição acima para os detalhes. Para mais ajuda:',
	'CoreUpdater_UpgradeComplete' => 'Atualização completa!',
	'CoreUpdater_WarningMessages' => 'Mensagens de alerta:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Erros durante atualização de plugins:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Nós automaticamente desativamos os seguintes plugins: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik foi atualizado com sucesso!',
	'CoreUpdater_ContinueToPiwik' => 'Continua no Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Atualiza automaticamente',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Há uma nova versão do Piwik disponível para atualização',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Você pode atualizar para a versão %s automaticamente ou baixar o pacote e instalar manualmente:',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik é incapaz de sobrescrever uma instalação atual. Você pode arrumar as permissões de diretório/arquivos ou download o pacote e instalar a versão %s manualmente:',
	'CoreUpdater_DownloadX' => 'Dowload %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'O Piwik One Click Update foi cancelado. Se você não pode consertar a mensagem de erro acima, é recomendado que você atualize manualmente o Piwik. %1$s Por favor cheque a %2$sDocumentaçao de atualização%3$s para começar!',
	'CoreUpdater_DownloadingUpdateFromX' => 'Baixando atualização de %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Descompactando a atualização',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Verificando os arquivos descompactados',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Criando uma cópia dos arquivos de configuração em %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Instalando a versão mais recente',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik atualizado com sucesso!',
	'CoreUpdater_EmptyDatabaseError' => 'O banco de dados %s está vazio. Você deve editar ou remover o seu arquivo de configuração do Piwik.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Sua versão %s do Piwik está atualizada.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Arquivo incompatível: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Arquivo vazio.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arquivo está incompleto: alguns arquivos estão faltando (ex. %s).',
	'Dashboard_PluginDescription' => 'Seu painel de ferramentas',
	'Dashboard_Dashboard' => 'Painel de Ferramentas',
	'Dashboard_DeleteWidgetConfirm' => 'Tem certeza que deseja excluir este widget do seu Painel?',
	'Dashboard_SelectWidget' => 'Selecione o widget a adicionar ao painel',
	'Dashboard_AddPreviewedWidget_js' => 'Adicionar o widget visualizado no preview ao painel',
	'Dashboard_WidgetPreview_js' => 'Visualização do Widget',
	'Dashboard_Close_js' => 'Fechar',
	'Dashboard_TitleWidgetInDashboard_js' => 'Widget já está no painel de ferramentas',
	'Dashboard_TitleClickToAdd_js' => 'Clique para adicionar ao painel de ferramentas',
	'Dashboard_LoadingWidget_js' => 'Carregando widget, aguarde...',
	'Dashboard_WidgetNotFound_js' => 'Widget não encontrado',
	'DBStats_PluginDescription' => 'Esse plugin relata o banco de dados MySQL usado pelas tabelas Piwik.',
	'DBStats_DatabaseUsage' => 'Uso do banco de dados',
	'DBStats_MainDescription' => 'O Piwik está armazenando todos os dados de análise de tráfego no banco de dados MySQL. Atualmente, as tabelas do Piwik estão usando %s.',
	'DBStats_LearnMore' => 'Apara aprender mais sobre como o Piwik processa os dados e como fazer o Piwik trabalhar bem para sites de médio e alto tráfego, confira a documentação %s.',
	'DBStats_Table' => 'Tabela',
	'DBStats_RowCount' => 'Contagem de linhas',
	'DBStats_DataSize' => 'Tamanho dos dados',
	'DBStats_IndexSize' => 'Tamanho do índice',
	'DBStats_TotalSize' => 'Tamanho total',
	'ExampleAPI_PluginDescription' => 'Plugin Exemplo: Como criar uma API para seu plugin, para exportar seus dados em multiplos formatos sem nenhum código especial?',
	'ExampleRssWidget_PluginDescription' => 'Plugin Exemplo: Como criar um novo widget que lê um RSS feed?',
	'ExampleUI_PluginDescription' => 'Plugin Exemplo: Esse plugin mostra como trabalhar com o Piwik UI: criar tabelas, gráficos, etc.',
	'Feedback_PluginDescription' => 'Envie seu FeedBack para a Equipe Piwik. Compartilhe suas ideias e sugestões conosco!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Você tem algum bug pra relatar ou alguma caracteristica para pedir?',
	'Feedback_ViewAnswersToFAQ' => 'Ver respostas para %s Questões Frequentemente Perguntadas %s',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Porque as visitas no meu website não estão sendo rastreadas?',
	'Feedback_HowToExclude' => 'Como excluir rastreamento de minhas visitas?',
	'Feedback_WhyWrongCountry' => 'Porque o Piwik mostra minha visita de um país errado?',
	'Feedback_HowToAnonymizeIP' => 'Como eu posso mascarar o endereço IP do visitante em meu banco de dados?',
	'Feedback_VisitTheForums' => 'Visite o %s Foruns %s',
	'Feedback_LearnWaysToParticipate' => 'Aprenda sobre todas as maneiras que você pode %s participar %s',
	'Feedback_SpecialRequest' => 'Você tem algum pedido especial para a equipe do Piwik?',
	'Feedback_ContactThePiwikTeam' => 'Entre em contato com a equipe Piwik!',
	'Feedback_IWantTo' => 'Eu quero:',
	'Feedback_CategoryShareStory' => 'Compartilhe uma história Piwik de sucesso',
	'Feedback_CategorySponsor' => 'Patrocinador Piwik',
	'Feedback_CategoryHire' => 'Contrate um consultor Piwik',
	'Feedback_CategorySecurity' => 'Relate um erro de segurança',
	'Feedback_MyEmailAddress' => 'Meu endereço de email:',
	'Feedback_MyMessage' => 'Minha mensagem:',
	'Feedback_DetailsPlease' => '(por favor inclua detalhes)',
	'Feedback_SendFeedback' => 'Envie FeedBack',
	'Feedback_ManuallySendEmailTo' => 'Por favor envie manualmente sua mensagem para',
	'Feedback_MessageSent' => 'Sua mensagem foi enviada para a equipe Piwik',
	'Feedback_ThankYou' => 'Obrigado por nos ajudar a fazer o Piwik melhor!',
	'Feedback_ThePiwikTeam' => 'A Equipe Piwik',
	'Feedback_ExceptionBodyLength' => 'A mensagem deve ter pelo menos %s caracteres.',
	'Feedback_ExceptionNoUrls' => 'A mensagem não pode conter uma URL para evitar mensagens spam.',
	'Goals_Goals' => 'Metas',
	'Goals_GoalsOverview' => 'Visão geral de metas',
	'Goals_GoalsManagement' => 'Gerenciamento de metas',
	'Goals_PluginDescription' => 'Crie metas e veja relatórios sobre suas metas de conversão: evolução sobre o tempo, lucro por visita, conversões por referencia, por palavra-chave, etc.',
	'Goals_ColumnConversions' => 'Conversões',
	'Goals_ColumnRevenue' => 'Lucro',
	'Goals_GoalX' => 'Metas %s',
	'Goals_OverallRevenue' => '%s lucro total',
	'Goals_OverallConversionRate' => '%s taxa total de conversão(visitas com uma meta completa)',
	'Goals_Conversions' => '%s conversões',
	'Goals_ConversionRate' => '%s taxa de conversão',
	'Goals_NoGoalsNeedAccess' => 'Apenas um Administrador ou um Super Usuário podem adicionar metas para um dado website. Por favor peça a um administrador Piwik  topara setar uma meta para seu website. <br>Rastrear metas é uma grande maneira de ajudar a entender e maximizar a performance de seu website!',
	'Goals_AddNewGoal' => 'Adicionar nova meta',
	'Goals_AddNewGoalOrEditExistingGoal' => '%sAdicionar nova meta%s ou %sEditar%s metas existentes',
	'Goals_AddGoal_js' => 'Adicionar meta',
	'Goals_UpdateGoal_js' => 'Atualizar meta',
	'Goals_DeleteGoalConfirm_js' => 'Tem certeza que deseja deletar a meta %s?',
	'Goals_CreateNewGOal' => 'Criar uma nova Meta',
	'Goals_ViewAndEditGoals' => 'Ver e Editar Metas',
	'Goals_GoalName' => 'Nome da meta',
	'Goals_GoalIsTriggered' => 'Meta está triggered',
	'Goals_GoalIsTriggeredWhen' => 'Meta está triggered quando',
	'Goals_WhenVisitors' => 'quando visitantes',
	'Goals_WhereThe' => 'onde o(a)',
	'Goals_Manually' => 'manualmente',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'A meta é manualmente triggered usando a API do Javascript trackGoal()',
	'Goals_VisitUrl' => 'Visitar a URL dada(página ou grupo de páginas)',
	'Goals_Filename' => 'nome do arquivo',
	'Goals_ExternalWebsiteUrl' => 'URL de website externo',
	'Goals_Download' => 'Baixar um arquivo',
	'Goals_ClickOutlink' => 'Clique num link para um website externo',
	'Goals_Optional' => '(opcional)',
	'Goals_WhereVisitedPageManuallyCallsJavascriptTrackerLearnMore' => 'onde a página visitada contem um chamado para o JavaScript piwikTracker.trackGoal() metodo (%slearn more%s)',
	'Goals_DefaultRevenue' => 'O lucro padrão da meta é',
	'Goals_DefaultRevenueHelp' => 'Por exemplo, um Form Contato submetido por um visitante pode valer $10 em média. Piwik ajudará a entender quão bem o segmento de seus visitantes está funcionando.',
	'Goals_ConversionsOverview' => 'Visão geral de conversões',
	'Goals_BestCountries' => 'Seus melhores países conversores são:',
	'Goals_BestKeywords' => 'Suas palavras-chave top de conversão são:',
	'Goals_BestReferers' => 'Seus melhores sites de conversão são:',
	'Goals_ReturningVisitorsConversionRateIs' => 'Taxa de retorno de visitantes convertidos é %s',
	'Goals_NewVisitorsConversionRateIs' => 'Taxa de conversão de novos usuários é %s',
	'Goals_Contains' => 'contem %s',
	'Goals_IsExactly' => 'é exatamente %s',
	'Goals_MatchesExpression' => 'corresponde com a expressão %s',
	'Goals_CaseSensitive' => 'Equivalencia case sensitive',
	'Goals_Pattern' => 'modelo',
	'Goals_ExceptionInvalidMatchingString' => 'Se você escolher \'correspondência exata\', a string correspondente deve ser uma URL que comece com %s. Por exemplo, "%s".',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => 'Aprenda mais sobre %s Rastreando Metas no Piwik %s na documentação do usuário.',
	'Installation_PluginDescription' => 'Processo de instalação do Piwik. A instalação normalmente é feita apenas uma vez. Se o arquivo de configuração config/config.inc.php é deletado, a instalação começará novamente.',
	'Installation_Installation' => 'Instalação',
	'Installation_InstallationStatus' => 'Status da Instalação',
	'Installation_PercentDone' => '%s %% Completo',
	'Installation_NoConfigFound' => 'O arquivo de configuração de relatórios não pode ser encontrado e você está tentando acessar uma página do Piwik.<br /><b>  » Você poderá <a href=\'index.php\'>instalar o Piwik agora</a></b><br /><small>Se você instalou o Piwik antes e possui algumas tabelas em seu banco de dados, não se preocupe, você poderá reutilizar as mesmas tabelas e manter os dados existentes!</small>',
	'Installation_DatabaseSetup' => 'Setup do banco de dados',
	'Installation_DatabaseSetupServer' => 'servidor de banco de dados',
	'Installation_DatabaseSetupPassword' => 'senha',
	'Installation_DatabaseSetupDatabaseName' => 'nome do banco de dados',
	'Installation_DatabaseSetupTablePrefix' => 'prefixo da tabela',
	'Installation_DatabaseSetupAdapter' => 'adaptador',
	'Installation_DatabaseErrorConnect' => 'Erro enquanto tentando conectar ao servidor do banco de dados',
	'Installation_DatabaseCheck' => 'check do banco de dados',
	'Installation_DatabaseServerVersion' => 'versão do servidor de banco de dados',
	'Installation_DatabaseClientVersion' => 'versão do banco de dados client',
	'Installation_DatabaseCreation' => 'Criação do banco de dados',
	'Installation_PleaseFixTheFollowingErrors' => 'Por favor, corrija os seguintes erros',
	'Installation_LargePiwikInstances' => 'Ajuda para instancias Piwik grandes',
	'Installation_JsTag' => 'Tag JavaScript',
	'Installation_JsTagArchivingHelp' => 'Para sites com médio e alto tráfego, verifique o documento <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">How to setup auto archiving page</a> para rodar o Piwik realmente rápido!',
	'Installation_Congratulations' => 'Parabéns',
	'Installation_CongratulationsHelp' => '<p>Parabéns! A sua instalação do Piwik está completa.</p><p>Certifique-se de ter colocado o código JavaScript em todas as suas páginas, e aguarde os seus primeiros visitantes!</p>',
	'Installation_ContinueToPiwik' => 'Continuar no Piwik',
	'Installation_SetupWebsite' => 'Configurar um website',
	'Installation_SetupWebSiteName' => 'nome do website',
	'Installation_SetupWebSiteURL' => 'URL do website',
	'Installation_Timezone' => 'fuso-horário do website',
	'Installation_SetupWebsiteError' => 'Ocorreu um erro ao tentar adicionar o website',
	'Installation_SetupWebsiteSetupSuccess' => 'Website %s criado com sucesso!',
	'Installation_SuperUserLogin' => 'login super usuário',
	'Installation_Password' => 'senha',
	'Installation_PasswordRepeat' => 'senha (repetir)',
	'Installation_SecurityNewsletter' => 'envie-me um email quando houver alertas de segurança e atualizações importantes',
	'Installation_CommunityNewsletter' => 'envie-me um email com atualizações da comunidade (novos plugins, novas funções, etc.)',
	'Installation_PasswordDoNotMatch' => 'senha não confere',
	'Installation_Requirements' => 'Requerimentos do Piwik',
	'Installation_Optional' => 'Opcional',
	'Installation_Legend' => 'Legenda',
	'Installation_Extension' => 'extensão',
	'Installation_SystemCheck' => 'Checagem do Sistema',
	'Installation_SystemCheckPhp' => 'Versão do PHP',
	'Installation_SystemCheckExtensions' => 'Outras extensões requeridas',
	'Installation_SystemCheckDatabaseHelp' => 'O Piwik requer ou a extensão mysqli ou ambas as extensões PDO e pdo_mysql.',
	'Installation_SystemCheckPdoAndMysqliHelp' => 'Num servidor Linux você poderá compilar o php com as seguintes opções: %1$s No seu php.ini, adicione as seguintes linhas: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Mais informações em: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> e <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Num servidor Windows você poderá adicionar as seguintes linhas ao seu php.ini: %s',
	'Installation_SystemCheckSplHelp' => 'Você precisa configurar e remontar o PHP com a Standard PHP Library (SPL) habilitada (por padrão).',
	'Installation_SystemCheckZlibHelp' => 'Você precisa configurar e remontar o PHP com suporte "zlib" ativado, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => 'Você precisa configurar e reconstruir PHP com suporte "iconv" habilitado, --with-iconv.',
	'Installation_SystemCheckWriteDirs' => 'Diretórios com permissão de escrita',
	'Installation_SystemCheckWriteDirsHelp' => 'Para resolver este problema no seu sistema Linux, tente digitar os seguintes comando(s)',
	'Installation_SystemCheckMemoryLimit' => 'Limite de Memória',
	'Installation_SystemCheckMemoryLimitHelp' => 'Em um site com alto tráfego, o processo de arquivamento pode exigir mais memória do que o atualmente permitido. Se necessário, mude a diretiva memory_limit no seu arquivo php.ini.',
	'Installation_SystemCheckOpenURL' => 'Abre URL',
	'Installation_SystemCheckOpenURLHelp' => 'Assinaturas de newsletters e notificações de atualização e atualizações em um clique requerem a extensão "curl", allow_url_fopen=On, ou fsockopen() ativada.',
	'Installation_SystemCheckGD' => 'GD > 2.x (gráficos)',
	'Installation_SystemCheckGDHelp' => 'Os sparklines (gráficos pequenos) não irão funcionar.',
	'Installation_SystemCheckFunctions' => 'Funções requeridas',
	'Installation_SystemCheckTimeLimitHelp' => 'Em um site com alto tráfego, executar o processo de arquivamento pode exigir mais memória do que o atualmente permitido. Se necessário, altere a diretiva max_execution_time no seu arquivo php.ini.',
	'Installation_SystemCheckMailHelp' => 'Mensagens de feedback e senha perdida não serão enviadas sem mail().',
	'Installation_SystemCheckParseIniFileHelp' => 'Essa função built-in foi desabilitada em seu host. Piwik tentará simular essa função mas poderá encontrar algumas restrições de segurança. Rastreador de performance também será impactado.',
	'Installation_SystemCheckGlobHelp' => 'Essa função embutida foi desabilitada em seu host. Piwik tentará simular essa função mas poderá encontrar mais adiante restrições de segurança. Funcionalidades podem ser impactadas.',
	'Installation_SystemCheckDebugBacktraceHelp' => 'View Factory não será permitida para criar views pelo módulo chamado.',
	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik usa funções anônimas para callbacks',
	'Installation_SystemCheckEvalHelp' => 'Requisitado pelo HTML QuickForm e sistema Smarty de templating.',
	'Installation_SystemCheckMbstringExtensionHelp' => 'A extensão mbstring é requisitada para caracteres multibyte na resposta da API usando valores separados por vírgula (CSV) ou valores separados por tab (TSB).',
	'Installation_SystemCheckMbstringFuncOverloadHelp' => 'Você deveria definir mbstring.func_overload para "0".',
	'Installation_SystemCheckFileIntegrity' => 'Integridade de arquivo.',
	'Installation_SystemCheckAutoUpdateHelp' => 'Nota: atualização do Piwik One Click requer permissões de escrita para as pastas Piwik e seu conteúdo.',
	'Installation_SystemCheckError' => 'Ocorreu um erro - precisa ser reparado antes de você poder prosseguir',
	'Installation_SystemCheckWarning' => 'Piwik vai funcionar corretamente mas alguns recursos podem não estar disponíveis',
	'Installation_Tables' => 'Criando as tabelas',
	'Installation_TablesWithSameNamesFound' => 'Algumas tabelas %1$s no seu banco de dados %2$s tem o mesmo nome das tabelas que o Piwik está tentando criar',
	'Installation_TablesFound' => 'As seguintes tabelas foram encontradas no banco de dados',
	'Installation_TablesWarningHelp' => 'Escolha reutilizar as tabelas existentes ou selecione uma nova instalação para apagar todas as informações no banco de dados.',
	'Installation_TablesReuse' => 'Reutilizar as tabelas existentes',
	'Installation_TablesDelete' => 'Excluir as tabelas encontradas',
	'Installation_TablesDeletedSuccess' => 'Tabelas Piwik excluídas com sucesso',
	'Installation_TablesCreatedSuccess' => 'Tabelas criadas com sucesso!',
	'Installation_DatabaseCreatedSuccess' => 'Banco de dados %s criado com sucesso!',
	'Installation_GoBackAndDefinePrefix' => 'Volte e defina um prefixo para as tabelas Piwik',
	'Installation_ConfirmDeleteExistingTables' => 'Tem certeza que quer apagar as tabelas: %s do seu banco de dados? AVISO: DADOS DESTAS TABELAS NÃO PODERÃO SER RECUPERADOS!',
	'Installation_Welcome' => 'Bem vindo!',
	'Installation_WelcomeHelp' => '<p>Piwik é um analisador de tráfego open source que torna fácil obter informações sobre os seus visitantes.</p><p>Este processo é dividido em %s passos fáceis e irá demorar por volta de 5 minutos.</p>',
	'Installation_ConfigurationHelp' => 'Seu arquivo de configuração Piwik parece estar desconfigurado. Você pode ou remover config/config.ini.php e fechar a instalação, ou corrigir as configurações de conexão com banco de dados.',
	'Installation_ErrorInvalidState' => 'Erro: parece que você está tentando pular um passo do processo de instalação, ou seus cookies estão desligados, ou o arquivo de configuração do Piwik já foi criado. %1$sTenha certeza de que seus cookies estão ativados%2$s e volte %3$spara a página inicial da instalação%4$s.',
	'LanguagesManager_PluginDescription' => 'Esse plugin mostrará uma lista de idiomas disponíveis para a interface do Piwik. O idioma selecionado salvará as preferencias para cada usuário.',
	'LanguagesManager_AboutPiwikTranslations' => 'Sobre traduções Piwik.',
	'Live_PluginDescription' => 'Espie seus visitantes, ao vivo, em tempo real!',
	'Live_LinkVisitorLog' => 'Ver log detalhado de visitantes',
	'Live_Actions' => 'Ações',
	'Live_Action' => 'Ação',
	'Live_VisitorLog' => 'Log de visitantes',
	'Live_Time' => 'Tempo',
	'Live_Referrer_URL' => 'URL referente',
	'Live_GoalType' => 'Tipo',
	'Live_GoalTime' => 'Primeira vez de conversão',
	'Live_GoalRevenue' => 'Rendimento',
	'Live_GoalDetails' => 'Detalhes',
	'Login_PluginDescription' => 'Plugin de autenticação de login, lendo as credenciais do arquivo config/config.inc.php para o Super Usuário, e do banco de dados para outros usuários. Pode ser facilmente substituido para introduzir um novo mecanismo (OpenID, htaccess, custom Auth, etc).',
	'Login_LoginPasswordNotCorrect' => 'Nome de usuário e senha incorretos',
	'Login_Password' => 'Senha',
	'Login_PasswordRepeat' => 'Senha (repetir)',
	'Login_ChangePassword' => 'Troca senha',
	'Login_LoginOrEmail' => 'Nome de Usuário ou E-mail',
	'Login_RememberMe' => 'Lembrar meu login',
	'Login_LogIn' => 'Entrar',
	'Login_Logout' => 'Sair',
	'Login_LostYourPassword' => 'Esqueceu a sua senha?',
	'Login_PasswordsDoNotMatch' => 'Senhas não conferem.',
	'Login_InvalidUsernameEmail' => 'Nome de usuário e/ou e-mail inválido',
	'Login_InvalidOrExpiredToken' => 'Token inválido ou expirado',
	'Login_ContactAdmin' => 'Possível razão: o seu host desabilitou a função mail(). <br />Por favor contacte o administrador do Piwik.',
	'Login_ExceptionPasswordMD5HashExpected' => 'É esperado que o parâmetro da senha seja um hash MD5 da senha.',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'O Super Usuário não pode ser autenticado usando o mecanismo "%s".',
	'Mobile_AnonymousAccess' => 'Acesso anônimo',
	'Mobile_AccessUrlLabel' => 'Url de Acesso Piwik',
	'Mobile_EnableGraphsLabel' => 'Mostrar gráficos',
	'Mobile_MultiChartLabel' => 'Mostrar sparklines',
	'Mobile_NetworkNotReachable' => 'Rede não encontrada',
	'Mobile_SaveSuccessError' => 'Por favor verifique configurações',
	'Mobile_YouAreOffline' => 'Desculpe, no momento você está offline.',
	'MultiSites_PluginDescription' => 'Mostra sumários/estatísticas executivas multi-site. No momento, mantida como plugin núcleo do Piwik.',
	'MultiSites_Evolution' => 'Evolução',
	'Provider_PluginDescription' => 'Relata o provedor dos visitantes.',
	'Provider_WidgetProviders' => 'Provedores',
	'Provider_ColumnProvider' => 'Provedor',
	'Provider_SubmenuLocationsProvider' => 'Lugares e Provedores',
	'Referers_PluginDescription' => 'Relata os dados referentes: mecanismos de pesquisa, palavras-chave, websites, campanha de rastreamento, entrada direta.',
	'Referers_Referers' => 'referentes',
	'Referers_SearchEngines' => 'Sistemas de Busca',
	'Referers_Keywords' => 'Palavras Chaves',
	'Referers_DirectEntry' => 'Entrada Direta',
	'Referers_Campaigns' => 'Campanhas',
	'Referers_Evolution' => 'Evolução no período',
	'Referers_Type' => 'Tipo de Referer',
	'Referers_ColumnRefererType' => 'Tipo de Referer',
	'Referers_ColumnSearchEngine' => 'Sistema de Busca',
	'Referers_ColumnWebsitePage' => 'Página da Web',
	'Referers_ColumnKeyword' => 'Palavra chave',
	'Referers_ColumnCampaign' => 'campanha',
	'Referers_DetailsByRefererType' => 'Detalhes por tipo de Referer',
	'Referers_TypeDirectEntries' => '%s entradas diretas',
	'Referers_TypeSearchEngines' => '%s de sistema de buscas',
	'Referers_TypeWebsites' => '%s de websites',
	'Referers_TypeCampaigns' => '%s de campanhas',
	'Referers_Distinct' => 'Referers distintos por tipo de Referer',
	'Referers_DistinctSearchEngines' => 'Sistemas de busca distintos',
	'Referers_DistinctKeywords' => 'Palavras chave distintas',
	'Referers_DistinctCampaigns' => 'Campanhas distintas',
	'Referers_DistinctWebsites' => 'Websites distintos',
	'Referers_UsingNDistinctUrls' => '(usando urls %s distintas)',
	'Referers_SubmenuSearchEngines' => 'Sistemas de Buscas e Palavras Chaves',
	'Referers_SubmenuCampaigns' => 'Campanhas',
	'Referers_WidgetKeywords' => 'Lista de Palavras Chave',
	'Referers_WidgetCampaigns' => 'Lista de Campanhas',
	'Referers_WidgetExternalWebsites' => 'Lista de Websites externos',
	'Referers_WidgetSearchEngines' => 'Melhores Sistemas de Busca',
	'Referers_WidgetOverview' => 'Visão Geral',
	'SecurityInfo_PluginDescription' => 'Baseada no PhpSecInfo do Consórsio de Segurança do PHP, esse plugin prove segurança da informação sobre seu ambiente PHP and oferece sugestões de melhoria. É uma ferramenta em uma aproximação segura multi camadas. Isso não substitui praticas de segurança no desenvolvimento nem auditar o código/aplicação.',
	'SecurityInfo_Security' => 'Segurança',
	'SecurityInfo_SecurityInformation' => 'Segurança da Informação PHP',
	'SecurityInfo_Test' => 'Teste',
	'SecurityInfo_Result' => 'Resultado',
	'SEO_SeoRankings' => 'Ranking SEO',
	'SEO_AlexaRank' => 'Rank Alexa',
	'SEO_DomainAge' => 'Idade de Domínio',
	'SEO_Pages' => 'Páginas',
	'SEO_SEORankingsFor' => 'Ranking SEO para %s',
	'SitesManager_PluginDescription' => 'Gerenciamento de websites no Piwik: adiciona um novo website, edita um existente, mostra código JavaScript para incluir em suas páginas. Todas as ações também estão disponíveis através da API.',
	'SitesManager_TrackingTags' => 'Rastreando tags para %s',
	'SitesManager_WebsitesManagement' => 'Gerenciamento de Sites',
	'SitesManager_MainDescription' => 'Seus relatórios de Web Analytics precisam de websites! Adiciona, atualiza, elimina websites, e mostra o JavaScript necessário para inserir em suas páginas.',
	'SitesManager_YouCurrentlyHaveAccessToNWebsites' => 'Você possui atualmente acessos a Websites %s',
	'SitesManager_OnlyOneSiteAtTime_js' => 'Você pode editar um website por vez. Por favor salve ou cancele as modificações do website atual %s.',
	'SitesManager_JsTrackingTag' => 'Tag de rastreamento JavaScript',
	'SitesManager_JsTrackingTagHelp' => 'Aqui está a tag de rastreamento JavaScript a ser incluída em todas as suas páginas',
	'SitesManager_ShowTrackingTag' => 'mostra tag de rastreamento',
	'SitesManager_NoWebsites' => 'Você não tem nenhum site para administrar.',
	'SitesManager_AddSite' => 'Adicionar novo Site',
	'SitesManager_NotFound' => 'Nenhum site encontrado para',
	'SitesManager_AliasUrlHelp' => 'É recomendado, mas não necessário, especificar as várias URLs que seus visitantes usam para acessar esse site, uma por linha. Pseudônimos de URLs para websites não aparecerão em Referencias > relatórios de websites. Note que não é necessário especificar as URLs com ou sem \'www\' como o Piwik considera automaticamente ambos.',
	'SitesManager_DeleteConfirm_js' => 'Tem certeza que deseja excluir o website %s?',
	'SitesManager_ExceptionDeleteSite' => 'Não é possível excluir este website já que ele é o único website registrado. Adiicone um novo website primeiro, depois exclua este.',
	'SitesManager_ExceptionNoUrl' => 'Você precisa especificar no mínimo uma URL para o site.',
	'SitesManager_ExceptionEmptyName' => 'O nome do site não pode ficar vazio.',
	'SitesManager_ExceptionInvalidUrl' => 'A URL \'%s\' não é uma URL válida.',
	'SitesManager_ExceptionInvalidTimezone' => 'O fuso-horário "%s" não é válido. Por favor inserir um fuso-horário válido.',
	'SitesManager_ExceptionInvalidCurrency' => 'A moeda "%s" não é válida. Por favor inserir um símbolo monetário válido (ex. %s)',
	'SitesManager_ExceptionInvalidIPFormat' => 'O IP para excluir "%s" não tem um formatio de IP válido (ex. %s)',
	'SitesManager_SuperUserCan' => 'O Super Usuário pode também %s especificar configurações globais %s para novos websites',
	'SitesManager_ExcludedIps' => 'IPs excluidos',
	'SitesManager_GlobalListExcludedIps' => 'Lista global de IPs excluidos',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'Os IPs abaixo serão excluidos por terem sido rastreados em todos os websites.',
	'SitesManager_ExcludedParameters' => 'Parâmetros Excluídos',
	'SitesManager_GlobalListExcludedQueryParameters' => 'Lista global de parâmetros Query URL para excluir',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => 'Os parâmetros Query URL abaixo serão excluidos das URLs em todos os websites',
	'SitesManager_ListOfQueryParametersToExclude' => 'Entre com a lista de parâmetros URL Query, uma por linha, para excluir os relátorios das páginas URL',
	'SitesManager_PiwikWillAutomaticallyExcludeCommonSessionParameters' => 'Piwik excluirá automaticamente a sessão comum de parâmetros (%s).',
	'SitesManager_HelpExcludedIps' => 'Entre com a lista de IPs, um por linha, que você deseja excluir por ter sido rastreado pelo Piwik. Você pode usar wildcards, ex: %1$s ou %2$s',
	'SitesManager_YourCurrentIpAddressIs' => 'Seu endereço de IP atual é %s',
	'SitesManager_SelectACity' => 'Selecione uma cidade',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Escolha uma cidade no mesmo fuso-horário que você',
	'SitesManager_ChangingYourTimezoneWillOnlyAffectDataForward' => 'Ao mudar seu fuso-horário apenas afetará os dados que vierem depois, não será aplicado retroativamente.',
	'SitesManager_AdvancedTimezoneSupportNotFound' => 'Suporte a fusos-horários avançados não encontrado em seu PHP (suportado no PHP >=5.2). Você pode ainda escolher um offset de UTC manual.',
	'SitesManager_UTCTimeIs' => 'UTC tempo é %s.',
	'SitesManager_Timezone' => 'Fuso horário',
	'SitesManager_GlobalWebsitesSettings' => 'Configurações globais de websites',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Fuso-horário padrão para novos websites',
	'SitesManager_SelectDefaultTimezone' => 'Você pode selecionar o fuso-horário para ser selecionado como padrão pra novos websites.',
	'SitesManager_Currency' => 'Moeda Corrente',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => 'O símbolo da moeda corrente será mostrado próximo às metas de lucro.',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Moeda corrente padrão para novos websites',
	'SitesManager_SelectDefaultCurrency' => 'Você pode selecionar a moeda corrente para ser setada como padrão para novos websites',
	'TranslationsAdmin_PluginDescription' => 'Ajude a traduzir o Piwik para seu idioma.',
	'TranslationsAdmin_MenuTranslations' => 'Traduções',
	'TranslationsAdmin_MenuLanguages' => 'Idiomas',
	'TranslationsAdmin_LanguageCode' => 'Código do Idioma',
	'TranslationsAdmin_Definition' => 'Definição',
	'TranslationsAdmin_DefaultString' => 'String Padrão (Inglês)',
	'TranslationsAdmin_TranslationString' => 'String de tradução (idioma atual: %s)',
	'TranslationsAdmin_Translations' => 'Traduções',
	'TranslationsAdmin_FixPermissions' => 'Por favor, conserte as permissões do sistema de arquivos',
	'TranslationsAdmin_AddLanguage' => 'Adicionar Idioma',
	'TranslationsAdmin_Export' => 'Exportar Idioma',
	'TranslationsAdmin_Import' => 'Importar Idioma',
	'UserCountry_PluginDescription' => 'Relata o país dos visitantes',
	'UserCountry_Country' => 'País',
	'UserCountry_Continent' => 'Continente',
	'UserCountry_DistinctCountries' => '%s países distintos',
	'UserCountry_Location' => 'Localização',
	'UserCountry_SubmenuLocations' => 'Locais',
	'UserCountry_country_ae' => 'Emirados Árabes Unidos',
	'UserCountry_country_af' => 'Afeganistão',
	'UserCountry_country_ag' => 'Antigua e Barbuda',
	'UserCountry_country_al' => 'Albânia',
	'UserCountry_country_am' => 'Armênia',
	'UserCountry_country_an' => 'Antilhas Holandesas',
	'UserCountry_country_aq' => 'Antártida',
	'UserCountry_country_as' => 'Samoa Americana',
	'UserCountry_country_at' => 'Áustria',
	'UserCountry_country_au' => 'Austrália',
	'UserCountry_country_ax' => 'Ilhas Aland',
	'UserCountry_country_az' => 'Azerbaijão',
	'UserCountry_country_ba' => 'Bósnia Herzegovina',
	'UserCountry_country_be' => 'Bélgica',
	'UserCountry_country_bg' => 'Bulgária',
	'UserCountry_country_bh' => 'Bahrein',
	'UserCountry_country_bn' => 'Brunei',
	'UserCountry_country_bo' => 'Bolívia',
	'UserCountry_country_br' => 'Brasil',
	'UserCountry_country_bt' => 'Butão',
	'UserCountry_country_bu' => 'Birmânia',
	'UserCountry_country_by' => 'Bielorússia',
	'UserCountry_country_ca' => 'Canadá',
	'UserCountry_country_cd' => 'Congo, República Democrática do',
	'UserCountry_country_cf' => 'República Centro-Africana',
	'UserCountry_country_ch' => 'Suíça',
	'UserCountry_country_ci' => 'Costa do Marfim',
	'UserCountry_country_ck' => 'Ilhas Cook',
	'UserCountry_country_cm' => 'Camarões',
	'UserCountry_country_co' => 'Colômbia',
	'UserCountry_country_cp' => 'Ilha Clipperton',
	'UserCountry_country_cs' => 'Sérvia e Montenegro',
	'UserCountry_country_cv' => 'Cabo Verde',
	'UserCountry_country_cx' => 'Ilha Christmas',
	'UserCountry_country_cy' => 'Chipre',
	'UserCountry_country_cz' => 'República Tcheca',
	'UserCountry_country_de' => 'Alemanha',
	'UserCountry_country_dk' => 'Dinamarca',
	'UserCountry_country_do' => 'República Dominicana',
	'UserCountry_country_dz' => 'Argélia',
	'UserCountry_country_ec' => 'Equador',
	'UserCountry_country_ee' => 'Estônia',
	'UserCountry_country_eg' => 'Egito',
	'UserCountry_country_eh' => 'Saara Ocidental',
	'UserCountry_country_er' => 'Eritréia',
	'UserCountry_country_es' => 'Espanha',
	'UserCountry_country_et' => 'Etiópia',
	'UserCountry_country_eu' => 'União Européia',
	'UserCountry_country_fi' => 'Finlândia',
	'UserCountry_country_fk' => 'Ilhas Falkland (Malvinas)',
	'UserCountry_country_fm' => 'Micronesia, Estados Federados da',
	'UserCountry_country_fo' => 'Ilhas Faroe',
	'UserCountry_country_fr' => 'França',
	'UserCountry_country_fx' => 'França, região Metropolitana',
	'UserCountry_country_ga' => 'Gabão',
	'UserCountry_country_gb' => 'Grã Bretanha',
	'UserCountry_country_gd' => 'Granada',
	'UserCountry_country_ge' => 'Geórgia',
	'UserCountry_country_gf' => 'Guiana Francesa',
	'UserCountry_country_gh' => 'Gana',
	'UserCountry_country_gl' => 'Groenlândia',
	'UserCountry_country_gm' => 'Gâmbia',
	'UserCountry_country_gn' => 'Guiné',
	'UserCountry_country_gp' => 'Guadalupe',
	'UserCountry_country_gq' => 'Guiné Equatorial',
	'UserCountry_country_gr' => 'Grécia',
	'UserCountry_country_gs' => 'South Georgia e Ilhas South Sandwich',
	'UserCountry_country_gw' => 'Guiné-Bissau',
	'UserCountry_country_gy' => 'Guiana',
	'UserCountry_country_hm' => 'Ilha Heard e Ilhas McDonald',
	'UserCountry_country_hr' => 'Croácia',
	'UserCountry_country_hu' => 'Hungria',
	'UserCountry_country_ic' => 'Ilhas Canárias',
	'UserCountry_country_id' => 'Indonésia',
	'UserCountry_country_ie' => 'Irlanda',
	'UserCountry_country_im' => 'Ilha de Man',
	'UserCountry_country_in' => 'Índia',
	'UserCountry_country_io' => 'Território Oceânico das Índias Britânicas',
	'UserCountry_country_iq' => 'Iraque',
	'UserCountry_country_ir' => 'Irã, República Islâmica do',
	'UserCountry_country_is' => 'Islândia',
	'UserCountry_country_it' => 'Itália',
	'UserCountry_country_jo' => 'Jordânia',
	'UserCountry_country_jp' => 'Japão',
	'UserCountry_country_ke' => 'Quênia',
	'UserCountry_country_kg' => 'Kirguistão',
	'UserCountry_country_kh' => 'Camboja',
	'UserCountry_country_kn' => 'Saint Kitts e Nevis',
	'UserCountry_country_kp' => 'Coréia, República Democrática Popular da',
	'UserCountry_country_kr' => 'Coréia, República da',
	'UserCountry_country_ky' => 'Ilhas Cayman',
	'UserCountry_country_kz' => 'Cazaquistão',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Líbano',
	'UserCountry_country_lc' => 'Santa Lúcia',
	'UserCountry_country_lr' => 'Libéria',
	'UserCountry_country_ls' => 'Lesoto',
	'UserCountry_country_lt' => 'Lituânia',
	'UserCountry_country_lu' => 'Luxemburgo',
	'UserCountry_country_lv' => 'Letônia',
	'UserCountry_country_ly' => 'Líbia',
	'UserCountry_country_ma' => 'Marrocos',
	'UserCountry_country_mc' => 'Mônaco',
	'UserCountry_country_md' => 'Moldávia, República da',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mh' => 'Ilhas Marshall',
	'UserCountry_country_mk' => 'Macedônia',
	'UserCountry_country_mn' => 'Mongólia',
	'UserCountry_country_mp' => 'Ilhas Marianas do Norte',
	'UserCountry_country_mq' => 'Martinica',
	'UserCountry_country_mr' => 'Mauritânia',
	'UserCountry_country_mu' => 'Ilhas Maurício',
	'UserCountry_country_mv' => 'Maldivas',
	'UserCountry_country_mx' => 'México',
	'UserCountry_country_my' => 'Malásia',
	'UserCountry_country_mz' => 'Moçambique',
	'UserCountry_country_na' => 'Namíbia',
	'UserCountry_country_nc' => 'Nova Caledônia',
	'UserCountry_country_ng' => 'Nigéria',
	'UserCountry_country_ni' => 'Nicarágua',
	'UserCountry_country_nl' => 'Holanda',
	'UserCountry_country_no' => 'Noruega',
	'UserCountry_country_nt' => 'Zona Neutra',
	'UserCountry_country_nz' => 'Nova Zelândia',
	'UserCountry_country_om' => 'Omã',
	'UserCountry_country_pa' => 'Panamá',
	'UserCountry_country_pf' => 'Polinésia Francesa',
	'UserCountry_country_pg' => 'Papua Nova Guiné',
	'UserCountry_country_ph' => 'Filipinas',
	'UserCountry_country_pk' => 'Paquistão',
	'UserCountry_country_pl' => 'Polônia',
	'UserCountry_country_pm' => 'Saint Pierre e Miquelon',
	'UserCountry_country_pr' => 'Porto Rico',
	'UserCountry_country_ps' => 'Território Palestino',
	'UserCountry_country_py' => 'Paraguai',
	'UserCountry_country_re' => 'Ilhas Reunião',
	'UserCountry_country_ro' => 'Romênia',
	'UserCountry_country_rs' => 'Sérvia',
	'UserCountry_country_ru' => 'Rússia',
	'UserCountry_country_rw' => 'Ruanda',
	'UserCountry_country_sa' => 'Arábia Saudita',
	'UserCountry_country_sb' => 'Ilhas Salomão',
	'UserCountry_country_sd' => 'Sudão',
	'UserCountry_country_se' => 'Suécia',
	'UserCountry_country_sf' => 'Finlândia',
	'UserCountry_country_sg' => 'Cingapura',
	'UserCountry_country_sh' => 'Santa Helena',
	'UserCountry_country_si' => 'Eslovênia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Eslováquia',
	'UserCountry_country_sl' => 'Serra Leoa',
	'UserCountry_country_so' => 'Somália',
	'UserCountry_country_st' => 'São Tome e Príncipe',
	'UserCountry_country_su' => 'Antiga U.R.S.S.',
	'UserCountry_country_sy' => 'República Árabe da Síria',
	'UserCountry_country_sz' => 'Suazilândia',
	'UserCountry_country_ta' => 'Tristão da Cunha',
	'UserCountry_country_tc' => 'Ilhas Turks e Caicos',
	'UserCountry_country_td' => 'Chade',
	'UserCountry_country_tf' => 'Territórios Franceses do Sul',
	'UserCountry_country_th' => 'Tailândia',
	'UserCountry_country_tj' => 'Tadjiquistão',
	'UserCountry_country_tl' => 'Timor Leste',
	'UserCountry_country_tm' => 'Turkmenistão',
	'UserCountry_country_tn' => 'Tunísia',
	'UserCountry_country_tp' => 'Timor Leste',
	'UserCountry_country_tr' => 'Turquia',
	'UserCountry_country_tt' => 'Trinidade e Tobago',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzânia, República Unida da',
	'UserCountry_country_ua' => 'Ucrânia',
	'UserCountry_country_uk' => 'Reino Unido',
	'UserCountry_country_us' => 'Estados Unidos da América',
	'UserCountry_country_uy' => 'Uruguai',
	'UserCountry_country_uz' => 'Uzbequistão',
	'UserCountry_country_va' => 'Cidade do Vaticano',
	'UserCountry_country_vc' => 'Saint Vincent e Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Ilhas Virgens Britânicas',
	'UserCountry_country_vi' => 'Ilhas Virgens Americanas',
	'UserCountry_country_vn' => 'Vietnã',
	'UserCountry_country_wf' => 'Wallis e Futuna',
	'UserCountry_country_ye' => 'Iêmen',
	'UserCountry_country_yu' => 'Iugoslávia',
	'UserCountry_country_za' => 'África do Sul',
	'UserCountry_country_zm' => 'Zâmbia',
	'UserCountry_country_zw' => 'Zimbabue',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'África',
	'UserCountry_continent_asi' => 'Ásia',
	'UserCountry_continent_amn' => 'América do Norte',
	'UserCountry_continent_ams' => 'América do Sul e Central',
	'UserCountryMap_map' => 'mapa',
	'UserCountryMap_worldMap' => 'mapa mundi',
	'UserCountryMap_toggleFullscreen' => 'Alternar tela cheia',
	'UserSettings_PluginDescription' => 'Relatórios diversas configurações de usuário: navegador, navegador família, sistema operacional, plugins, resolução, configurações globais.',
	'UserSettings_VisitorSettings' => 'Configurações dos visitantes',
	'UserSettings_BrowserFamilies' => 'Família de Navegadores',
	'UserSettings_Browsers' => 'Navegadores',
	'UserSettings_Configurations' => 'Configurações',
	'UserSettings_OperatingSystems' => 'Sistemas Operacionais',
	'UserSettings_Resolutions' => 'Resoluções',
	'UserSettings_ColumnBrowserFamily' => 'Família do Navegador',
	'UserSettings_ColumnBrowser' => 'Navegador',
	'UserSettings_ColumnConfiguration' => 'Configuração',
	'UserSettings_ColumnOperatingSystem' => 'Sistema Operacional',
	'UserSettings_ColumnResolution' => 'Resolução',
	'UserSettings_ColumnTypeOfScreen' => 'Tipo de tela',
	'UserSettings_WidgetResolutions' => 'Resoluções de Tela',
	'UserSettings_WidgetBrowsers' => 'Navegador dos Visitantes',
	'UserSettings_WidgetPlugins' => 'Lista de Plugins',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Nota: a detecção de plugins não funciona no Internet Explorer. Esse relatório é baseado apenas em navegadores não IE.',
	'UserSettings_WidgetBrowserFamilies' => 'Navegadores por Família',
	'UserSettings_WidgetOperatingSystems' => 'Sistemas Operacionais',
	'UserSettings_WidgetGlobalVisitors' => 'Configuração Global de Visitante',
	'UserSettings_SubmenuSettings' => 'Configurações',
	'UsersManager_PluginDescription' => 'Gerenciamento de Usuários no Piwik: adicionar novo usuário, editar um existente, atualizar permissões. Todas as ações também estão disponíveis na API.',
	'UsersManager_UsersManagement' => 'Gerenciamento de usuários',
	'UsersManager_UsersManagementMainDescription' => 'Crie novos usuários ou atualize os usuários existentes. Você poderá então ajustar as permissões deles acima.',
	'UsersManager_ManageAccess' => 'Gerenciar acesso',
	'UsersManager_MainDescription' => 'Decida quais usuários terão acesso ao Piwik nos seus websites. Você pode também ajustar as permissões em todos os websites de uma só vez.',
	'UsersManager_AllWebsites' => 'Todos os websites',
	'UsersManager_ApplyToAllWebsites' => 'Aplicar a todos os websites',
	'UsersManager_User' => 'Usurário',
	'UsersManager_PrivNone' => 'Sem acesso',
	'UsersManager_PrivView' => 'Ver',
	'UsersManager_ChangeAllConfirm' => 'Você tem certeza que deseja alterar as permissões de %s em todos os websites?',
	'UsersManager_Password' => 'Senha',
	'UsersManager_Alias' => 'Apelido',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'O pseudônimo do Super Usuário não pode ser alterado.',
	'UsersManager_ReportToLoadByDefault' => 'Relate para carregar por padrão',
	'UsersManager_ReportDateToLoadByDefault' => 'Relate data para carregar por padrão',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'Para usuários anônimos, reportar dara para carregar por padrão',
	'UsersManager_ExcludeVisitsViaCookie' => 'Excluir suas visitas usando cookie',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%s Suas visitas são ignoradas pelo Piwik em %s %s (o Piwik ignora o cookie encontrado em seu navegador).',
	'UsersManager_YourVisitsAreNotIgnored' => '%sSuas visitas não são ignoradas pelo Piwik%s (o Piwik ignora o cookie não encotrado em seu navegador)',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Clique aqui para deletar o cookie e deixar o Piwik rastrear suas visitas',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => 'Clique aqui para setar um cookie que excluirá suas visitas em websites rastrados pelo Piwik em %s',
	'UsersManager_Edit' => 'Editar',
	'UsersManager_AddUser' => 'Adicionar novo usuário',
	'UsersManager_MenuUsers' => 'Usuários',
	'UsersManager_MenuUserSettings' => 'Configurações de usuário',
	'UsersManager_MenuAnonymousUserSettings' => 'Configurações de usuário anônimo',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Quando usuários não estão logados e visitam o Piwik, eles deveriam acessar',
	'UsersManager_ChangePassword' => 'Mudar senha',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Se você gostaria de mudar a senha, digite uma nova. Senão, deixe em branco.',
	'UsersManager_TypeYourPasswordAgain' => 'Digite a nova senha novamente.',
	'UsersManager_TheLoginScreen' => 'Tela de login',
	'UsersManager_DeleteConfirm_js' => 'Tem certeza que deseja apagar o usuário %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Seu nome de usuário não pode ser alterado.',
	'UsersManager_ExceptionLoginExists' => 'Usuário \'%s\' já existe.',
	'UsersManager_ExceptionEmailExists' => 'Usuário com o e-mail \'%s\' já existe.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'O login deve conter entre %1$s e %2$s caracteres e conter apenas letras, números ou os caracteres \'_\' ou\'.\'',
	'UsersManager_ExceptionInvalidEmail' => 'O e-mail não tem um formato válido.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'O usuário \'%s\' não existe assim não é possível excluí-lo.',
	'UsersManager_ExceptionAdminAnonymous' => 'Você não pode conceder acesso \'admin\' para o usuário \'anonymous\' .',
	'UsersManager_ExceptionEditAnonymous' => 'O usuário anonymous não pode ser editado ou apagado. Ele é usado pelo sistema para definir um usuário que ainda não não entrou. Por examplo, você pode tornar as estatísticas públicas concedendo acesso \'view\' para o usuário \'anonymous\'.',
	'UsersManager_ExceptionSuperUser' => 'O usuário requisitado é o Super Usuário e não pode ser alterado, editado ou apagado através da API. Você pode editar manualmente os detalhes do Super Usuário no seu arquivo de configurações do Piwik.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Usuário \'%s\' não existe.',
	'UsersManager_ExceptionAccessValues' => 'O parâmetro de acesso deve conter os seguintes valores: [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth está esperando uma senha MD5-hashed (32 chars long string). Por favor chame a função md5() na senha antes de chamar esse método.',
	'VisitFrequency_PluginDescription' => 'Reportar diferentes estatísticas sobre os visitantes que retornam versus os visitantes pela primeira vez.',
	'VisitFrequency_Evolution' => 'Evolução no Período',
	'VisitFrequency_ColumnReturningVisits' => 'Visitantes de Retorno',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Ações de Visitantes de Retorno',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'Taxa. Duração das visitas para visitantes que retornam',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Taxa da saída para Visitantes de Retorno',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Taxa. Ações por visita retornada',
	'VisitFrequency_ReturnVisits' => '%s visitantes de retorno',
	'VisitFrequency_ReturnActions' => '%s ações por visitante de retorno',
	'VisitFrequency_ReturnAvgActions' => '%s ações por visita retornada',
	'VisitFrequency_ReturnBounceRate' => '%s visitantes de retorno deixaram o website após uma página',
	'VisitFrequency_WidgetOverview' => 'Visão Geral da Frequência',
	'VisitFrequency_WidgetGraphReturning' => 'Gráfico de Visitantes de Retorno',
	'VisitFrequency_SubmenuFrequency' => 'Frequência',
	'VisitorInterest_PluginDescription' => 'Relatórios sobre o interesse do visitante: número de páginas visualizadas, tempo gasto no website.',
	'VisitorInterest_VisitsPerDuration' => 'Visitas por duração de visitas',
	'VisitorInterest_VisitsPerNbOfPages' => 'Visitas pelo número de páginas',
	'VisitorInterest_ColumnVisitDuration' => 'Duração da visita',
	'VisitorInterest_ColumnPagesPerVisit' => 'Páginas por visita',
	'VisitorInterest_WidgetLengths' => 'Duração das Visitas',
	'VisitorInterest_WidgetPages' => 'Páginas por Visita',
	'VisitorInterest_Engagement' => 'Compromisso',
	'VisitorInterest_OnePage' => '1 página',
	'VisitorInterest_NPages' => '%s páginas',
	'VisitsSummary_PluginDescription' => 'Relata os números gerais Analytics: visitas, visitantes únicos, número de ações, taxas, etc.',
	'VisitsSummary_VisitsSummary' => 'Resumo dos Visitantes',
	'VisitsSummary_NbVisits' => '%s visitas',
	'VisitsSummary_NbUniqueVisitors' => '%s visitantes únicos',
	'VisitsSummary_NbActionsDescription' => '%s ações (visualizações de páginas, downloads e links externos)',
	'VisitsSummary_MaxNbActions' => '%s ações máximas em uma visita',
	'VisitsSummary_NbVisitsBounced' => '%s visitantes saíram (deixaram o website após uma página)',
	'VisitsSummary_GenerateTime' => '%s segundos para gerar a página',
	'VisitsSummary_GenerateQueries' => '%s consultas executadas',
	'VisitsSummary_WidgetLastVisits' => 'Gráfico dos últimos visitantes',
	'VisitsSummary_WidgetVisits' => 'Visão Geral dos Visitantes',
	'VisitsSummary_WidgetLastVisitors' => 'Gráfico dos últimos visitantes únicos',
	'VisitsSummary_WidgetOverviewGraph' => 'Visão Geral com Gráfico',
	'VisitsSummary_SubmenuOverview' => 'Visão Geral',
	'VisitTime_PluginDescription' => 'Relata a hora local e a hora do servidor. Informação de hora do servidor pode ser útil para relacionar a manutenção do website.',
	'VisitTime_LocalTime' => 'Visitas pelo horário local',
	'VisitTime_ServerTime' => 'Visitas pelo horário do servidor',
	'VisitTime_ColumnServerTime' => 'Horário do servidor',
	'VisitTime_ColumnLocalTime' => 'Horário local',
	'VisitTime_WidgetLocalTime' => 'Visitas pelo horário local',
	'VisitTime_WidgetServerTime' => 'Visitas pelo horário do servidor',
	'VisitTime_SubmenuTimes' => 'Horários',
	'Widgetize_PluginDescription' => 'O plugin faz ficar muito fácil exportar qualquer widget Piwik para seu blog, website ou em Igoogle e Netvibes!',
);
